@@ -1,38 +1,31 @@
 import dataclasses
-import fnmatch
+import os
+from fnmatch import fnmatchcase
 from pathlib import Path
-from typing import Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional
 
 import click
-from robotcode.core.dataclasses import as_dict, encode_case
-from robotcode.plugin import Application, OutputFormat, pass_application
-from robotcode.plugin.click_helper import add_options
+from robotcode.core.dataclasses import encode_case
+from robotcode.plugin import Application, OutputFormat, UnknownError, pass_application
 from robotcode.robot.config.loader import (
+    DiscoverdBy,
     find_project_root,
     load_config_from_path,
 )
-from robotcode.robot.config.model import LibDocProfile, RebotProfile, RobotConfig, TestDocProfile
+from robotcode.robot.config.model import LibDocProfile, RebotProfile, RobotConfig, RobotProfile, TestDocProfile
 from robotcode.robot.config.utils import get_config_files
 
-from ._common import format_option
-
 
 @click.group(
     invoke_without_command=False,
 )
-@pass_application
-def config(
-    app: Application,
-) -> Union[str, int, None]:
+def config() -> None:
     """\
-    Commands to give informations about Robot Framework configuration.
+    View configuration informations.
     """
 
-    return 0
-
 
 @config.command
-@add_options(format_option)
 @click.option(
     "-s", "--single", "single", is_flag=True, default=False, help="Shows single files, not the combined config."
 )
@@ -40,12 +33,11 @@ def config(
 @pass_application
 def show(
     app: Application,
-    format: OutputFormat,
     single: bool,
     paths: List[Path],
-) -> Union[str, int, None]:
+) -> None:
     """\
-    Shows the Robot Framework configuration.
+    Shows the current _robot_ configuration.
 
     Takes a list of PATHS or if no PATHS are given, takes the current working directory,
     to search for configuration files and prints the current configuration.
@@ -55,47 +47,41 @@ def show(
     ```
     robotcode config show
     robotcode config show tests/acceptance/first.robot
-    robotcode config show --format json
+    robotcode --format json config show
     ```
     """
-
-    config_files, _, _ = get_config_files(paths, app.config.config_files, verbose_callback=app.verbose)
-
     try:
+        config_files, _, _ = get_config_files(paths, app.config.config_files, verbose_callback=app.verbose)
+
         if single:
             for file, _ in config_files:
                 config = load_config_from_path(file)
                 click.secho(f"File: {file}")
-                app.print_dict(as_dict(config, remove_defaults=True), format)
+                app.print_data(config, remove_defaults=True, default_output_format=OutputFormat.TOML)
 
-            return 0
+            return
 
         config = load_config_from_path(*config_files)
 
-        app.print_dict(as_dict(config, remove_defaults=True), format)
+        app.print_data(config, remove_defaults=True, default_output_format=OutputFormat.TOML)
 
-    except (TypeError, ValueError) as e:
-        raise click.ClickException(str(e)) from e
-
-    return 0
+    except (TypeError, ValueError, OSError) as e:
+        raise UnknownError(str(e)) from e
 
 
 @config.command
 @click.argument("paths", type=click.Path(exists=True, path_type=Path), nargs=-1, required=False)
+@click.argument("user", type=bool, default=False)
 @pass_application
-def files(
-    app: Application,
-    paths: List[Path],
-) -> Union[str, int, None]:
+def files(app: Application, paths: List[Path], user: bool = False) -> None:
     """\
-    Shows Robot Framework configuration files.
+    Search for _robot_ configuration files and list them.
 
     Takes a list of PATHS or if no PATHS are given, takes the current working directory,
     to search for configuration files and prints them.
 
     \b
     Examples:
-
     ```
     robotcode config files
     robotcode config files tests/acceptance/first.robot
@@ -103,15 +89,28 @@ def files(
     """
 
     try:
-        config_files, _, _ = get_config_files(paths, app.config.config_files, verbose_callback=app.verbose)
+        config_files, _, discovered_by = get_config_files(paths, app.config.config_files, verbose_callback=app.verbose)
 
-        for config_file, _ in config_files:
-            click.echo(config_file)
+        result: Dict[str, Any] = {
+            "files": [{"path": str(file), "type": type} for file, type in config_files],
+        }
 
-        return 0
+        messages = []
+        if discovered_by == DiscoverdBy.NOT_FOUND:
+            messages += ["Cannot detect root folder. 😥"]
+        elif not config_files:
+            messages += ["Cannot find any configuration file. 😥"]
+        if messages:
+            result["messages"] = messages
 
-    except FileNotFoundError as e:
-        raise click.ClickException(str(e)) from e
+        if app.config.output_format is None or app.config.output_format == OutputFormat.TEXT:
+            for entry in result["files"]:
+                app.echo(f'{entry["path"]} ({entry["type"].value})')
+        else:
+            app.print_data(result)
+
+    except OSError as e:
+        raise UnknownError(str(e)) from e
 
 
 @config.command
@@ -120,16 +119,15 @@ def files(
 def root(
     app: Application,
     paths: List[Path],
-) -> Union[str, int, None]:
+) -> None:
     """\
-    Shows the root of the Robot Framework project.
+    Searches for the root folder of the _robot_ project and prints them.
 
     Takes a list of PATHS or if no PATHS are given, takes the current working directory,
     to search for the root of the project and prints this.
 
     \b
     Examples:
-
     ```
     robotcode config root
     robotcode config root tests/acceptance/first.robot
@@ -138,19 +136,30 @@ def root(
 
     root_folder, discovered_by = find_project_root(*(paths or []))
 
-    if root_folder is None:
-        raise click.ClickException("Cannot detect root folder for project. 😥")
+    if root_folder is None and (app.config.output_format is None or app.config.output_format == OutputFormat.TEXT):
+        raise click.ClickException("Cannot detect root folder. 😥")
 
-    click.echo(f"{root_folder} (discovered by {discovered_by})")
+    result: Dict[str, Any] = {
+        "root": {"path": str(root_folder) if root_folder is not None else None, "discoverdBy": discovered_by}
+    }
 
-    return 0
+    messages = []
+    if discovered_by == DiscoverdBy.NOT_FOUND:
+        messages += ["Cannot detect root folder. 😥"]
+
+    if messages:
+        result["messages"] = messages
+
+    if app.config.output_format is None or app.config.output_format == OutputFormat.TEXT:
+        click.echo(f"{root_folder} (discovered by {discovered_by.value})")
+    else:
+        app.print_data(result)
 
 
 @config.group
 @pass_application
-def info(app: Application) -> Union[str, int, None]:
+def info(app: Application) -> None:
     """Shows informations about possible configuration settings."""
-    return 0
 
 
 def get_config_fields() -> Dict[str, Dict[str, str]]:
@@ -162,6 +171,16 @@ def get_config_fields() -> Dict[str, Dict[str, str]]:
             "description": field.metadata.get("description", "").strip(),
         }
 
+    for field in dataclasses.fields(RobotProfile):
+        field_name_encoded = encode_case(RobotProfile, field)
+        if field_name_encoded in result:
+            continue
+
+        result["[profile]." + field_name_encoded] = {
+            "type": str(field.type),
+            "description": field.metadata.get("description", "").strip(),
+        }
+
     for field in dataclasses.fields(RebotProfile):
         field_name_encoded = encode_case(RebotProfile, field)
         result["rebot." + field_name_encoded] = {
@@ -189,7 +208,7 @@ def get_config_fields() -> Dict[str, Dict[str, str]]:
 @info.command()
 @click.argument("name", type=str, nargs=-1)
 @pass_application
-def list(app: Application, name: Optional[List[str]] = None) -> Union[str, int, None]:
+def list(app: Application, name: Optional[List[str]] = None) -> None:
     """\
     Lists all possible configuration settings.
 
@@ -197,7 +216,6 @@ def list(app: Application, name: Optional[List[str]] = None) -> Union[str, int,
 
     \b
     Examples:
-
     ```
     robotcode config info list
     robotcode config info list rebot.*
@@ -209,18 +227,22 @@ def list(app: Application, name: Optional[List[str]] = None) -> Union[str, int,
 
     config_fields = get_config_fields()
 
+    result = []
     for n in name:
         for field in config_fields.keys():
-            if fnmatch.fnmatchcase(field, n):
-                app.echo(field)
+            if fnmatchcase(field, n):
+                result.append(field)
 
-    return 0
+    if app.config.output_format is None or app.config.output_format == OutputFormat.TEXT:
+        app.echo_via_pager(os.linesep.join(result))
+    else:
+        app.print_data({"names": result})
 
 
 @info.command()
 @click.argument("name", type=str, nargs=-1)
 @pass_application
-def desc(app: Application, name: Optional[List[str]] = None) -> Union[str, int, None]:
+def desc(app: Application, name: Optional[List[str]] = None) -> None:
     """\
     Shows the description of the specified configuration settings.
 
@@ -229,7 +251,6 @@ def desc(app: Application, name: Optional[List[str]] = None) -> Union[str, int,
 
     \b
     Examples:
-
     ```
     robotcode config info desc
     robotcode config info desc python-path
@@ -240,15 +261,30 @@ def desc(app: Application, name: Optional[List[str]] = None) -> Union[str, int,
     if not name:
         name = ["*"]
 
-    config_fields = get_config_fields()
+    config_fields = [
+        (field, value) for field, value in get_config_fields().items() if any(fnmatchcase(field, n) for n in name)
+    ]
 
-    for n in name:
-        for field, value in config_fields.items():
-            if fnmatch.fnmatchcase(field, n):
-                output = f"## {field}\n\n"
-                output += f"Type: {value['type']}\n\n"
-                output += value["description"] + "\n\n"
+    if app.config.output_format is None or app.config.output_format == OutputFormat.TEXT:
+        output = ""
+        for field, value in config_fields:
+            output += f"## {field}\n\n"
+            type = (
+                value["type"]
+                .replace("typing.", "")
+                .replace("robotcode.robot.config.model.", "")
+                .replace("NoneType", "None")
+            )
+            output += f"Type: {type}\n\n"
+            output += value["description"] + "\n\n"
 
-                app.echo_as_markdown(output)
-
-    return 0
+        app.echo_as_markdown(output)
+    else:
+        app.print_data(
+            {
+                "descriptions": [
+                    {"name": field, "type": value["type"], "description": value["description"]}
+                    for field, value in config_fields
+                ]
+            }
+        )
